@@ -3,46 +3,9 @@ from discord import User, TextChannel, utils
 from datetime import datetime
 import typing
 
-from discordbot.config import INVITE_OWNER, INVITE_BOT, SPAM_ALLOWED
+from discordbot.config import INVITE_OWNER, INVITE_BOT, SPAM_ALLOWED, REGELN
 #from discordbot.errors import ErrorMessage
 
-REGELN = {
-    "1) Verhalten":
-        [
-            "Sei nett zu anderen Leuten und behandle sie so, wie auch du behandelt werden möchtest!", 
-            "Beleidige keine anderen Leute!",
-            "Benutze anständige Sprache!",
-            "Bleib beim Thema!",
-        ],
-    "2) Text":
-        [
-            "Spamming ist verboten!", 
-            "Werbung ohne Erlaubnis eines Administrators ist verboten!",
-        ],
-    "3) Ton":
-        [
-            "Benutze keinen Stimmverzerrer!", 
-            "Mache keine unnötigen Hintergrundgeräusche!", 
-            "Channel Hopping bitte unterlassen!", 
-            "Sprachaufnahmen sind nur mit Erlaubnis aller Teilnehmer gestattet!",
-        ],
-    "4) NSFW":
-        [
-            "Anstössige Inhalte ausserhalb NSFW-Kanälen werden sofort gelöscht und der Autor mit einem Bann/Mute bestraft!", 
-        ],
-    "5) Sicherheit":
-        [
-            "Anweisungen von Moderatoren, Supportern und Admins müssen befolgt werden!",
-            "Falls jemand ohne Grund nach deinen persönlichen Daten fragt, ignoriere bitte die Nachricht und meldet sie einem Admin oder dem Serverbesitzer! Bitte melde den Benutzer ebenfalls bei Discord!",
-            "Sende nie jemandem euer Passwort!",
-        ],
-    "6) Empfehlungen":
-        [
-            "Habe Spass!",
-        ],
-}
-
-
 class Basic(commands.Cog):
     def __init__(self, bot):
         self.bot = bot
@@ -69,6 +32,7 @@ class Basic(commands.Cog):
         help="Benutze /say <Text> und der Bot schickt dir den Text zurück",
         usage="<Text>"
         )
+    @commands.has_permissions(manage_messages=True)
     async def say(self, ctx, text:str, *args):
         txt = " ".join((text,)+args)
         await ctx.send(txt)
@@ -146,14 +110,15 @@ class Basic(commands.Cog):
                 try:
                     invite = utils.get(list(await ctx.guild.invites()), max_age=0, max_uses=0)
                     if not invite:
-                        invite = await ctx.channel.create_invite()
+                        invite = await (ctx.guild.system_channel or ctx.channel).create_invite()
                 except:
                     invite = None
 
-        if invite:
-            await ctx.sendEmbed(title="Einladungen", fields=[("Dieser Server", invite.url or "Unbekannt"), ("Bot Owner Server", INVITE_OWNER), ("Bot", INVITE_BOT)])
-        else:
-            await ctx.sendEmbed(title="Einladungen", fields=[("Bot Owner Server",INVITE_OWNER), ("Bot",INVITE_BOT)])
+        gc = len(ctx.bot.guilds)
+        desc = f"Ich bin bereits auf {gc} Guild(s)! Du möchtest, dass diese Zahl steigt? Kein Problem! Du möchtest Leute auf diesen Server einladen? Auch kein Problem!"
+
+        inviteurl = invite.url if invite and invite.url else None
+        await ctx.sendEmbed(title="Einladungen", description=desc, fields=[("Dieser Server", f"[Beitreten]({inviteurl})" if inviteurl else "Unbekannt"), ("Bot Owner Server", f"[Beitreten]({INVITE_OWNER})"), ("Bot", f"[Beitreten]({INVITE_BOT})")])
 
 def setup(bot):
     bot.add_cog(Basic(bot))
