@@ -3,7 +3,7 @@
 from asgiref.sync import sync_to_async
 
 from discord.ext import commands, tasks
-from discord import Embed, utils, PermissionOverwrite, Color, NotFound, User, Member
+from discord import Embed, utils, PermissionOverwrite, Color, NotFound, User, Member, ChannelType
 
 from django.utils import timezone
 
@@ -12,6 +12,7 @@ from datetime import timedelta
 from discordbot.models import AmongUsGame, AMONGUS_PLAYER_COLORS, AMONGUS_EMOJI_COLORS, VierGewinntGame, VIERGEWINNT_NUMBER_EMOJIS
 from discordbot.botmodules.serverdata import DjangoConnection
 from discordbot.botmodules import apis
+from discordbot.errors import ErrorMessage
 
 import requests
 import os
@@ -73,60 +74,62 @@ class Games(commands.Cog):
             channel = await self.bot.fetch_channel(payload.channel_id)
             message = await channel.fetch_message(payload.message_id)
 
-            ### AmongUs
+            if message.author.id == self.bot.user.id:
 
-            if (emoji in AMONGUS_EMOJI_COLORS or emoji == DELETE) and await DjangoConnection._hasAmongUsGame(text_message_id=payload.message_id):
-                try:
-                    await message.remove_reaction(emoji, payload.member)
-                except:
-                    pass
+                ### AmongUs
 
-                game = await DjangoConnection._getAmongUsGame(text_message_id=payload.message_id)
+                if (emoji in AMONGUS_EMOJI_COLORS or emoji == DELETE) and await DjangoConnection._has(AmongUsGame, text_message_id=payload.message_id):
+                    try:
+                        await message.remove_reaction(emoji, payload.member)
+                    except:
+                        pass
 
-                if emoji == DELETE:
-                    await game.remove_user(userid=payload.user_id)
-                else:
-                    c = AMONGUS_EMOJI_COLORS[payload.emoji.name]
-                    await game.set_user(userid=payload.user_id, color=c)
+                    game = await DjangoConnection._getAmongUsGame(text_message_id=payload.message_id)
 
-            ### VierGewinnt
+                    if emoji == DELETE:
+                        await game.remove_user(userid=payload.user_id)
+                    else:
+                        c = AMONGUS_EMOJI_COLORS[payload.emoji.name]
+                        await game.set_user(userid=payload.user_id, color=c)
 
-            if (emoji in VIERGEWINNT_NUMBER_EMOJIS) and await DjangoConnection._has(VierGewinntGame, message_id=payload.message_id):
-                try:
-                    await message.remove_reaction(emoji, payload.member)
-                except:
-                    pass
+                ### VierGewinnt
 
-                game = await DjangoConnection._get(VierGewinntGame, message_id=payload.message_id)
+                if (emoji in VIERGEWINNT_NUMBER_EMOJIS) and await DjangoConnection._has(VierGewinntGame, message_id=payload.message_id):
+                    try:
+                        await message.remove_reaction(emoji, payload.member)
+                    except:
+                        pass
 
-                if not game.finished:
-                    n = VIERGEWINNT_NUMBER_EMOJIS.index(emoji)
+                    game = await DjangoConnection._get(VierGewinntGame, message_id=payload.message_id)
 
-                    if game.process(n, payload.user_id):
-                        await DjangoConnection._save(game)
+                    if not game.finished:
+                        n = VIERGEWINNT_NUMBER_EMOJIS.index(emoji)
 
-                        embed = self.bot.getEmbed(
-                            title=f"Vier Gewinnt (#{game.pk})",
-                            color=0x0078D7,
-                            description=game.get_description()
-                        )
+                        if game.process(n, payload.user_id):
+                            await DjangoConnection._save(game)
 
-                        await message.edit(embed=embed)
+                            embed = self.bot.getEmbed(
+                                title=f"Vier Gewinnt (#{game.pk})",
+                                color=0x0078D7,
+                                description=game.get_description()
+                            )
 
-                    if game.process_bot():
-                        await DjangoConnection._save(game)
+                            await message.edit(embed=embed)
 
-                        embed = self.bot.getEmbed(
-                            title=f"Vier Gewinnt (#{game.pk})",
-                            color=0x0078D7,
-                            description=game.get_description()
-                        )
+                        if game.process_bot():
+                            await DjangoConnection._save(game)
 
-                        await message.edit(embed=embed)
+                            embed = self.bot.getEmbed(
+                                title=f"Vier Gewinnt (#{game.pk})",
+                                color=0x0078D7,
+                                description=game.get_description()
+                            )
 
-                    if game.finished:
-                        for emoji in VIERGEWINNT_NUMBER_EMOJIS[:game.width]:
-                            await message.remove_reaction(emoji, self.bot.user)
+                            await message.edit(embed=embed)
+
+                        if game.finished:
+                            for emoji in VIERGEWINNT_NUMBER_EMOJIS[:game.width]:
+                                await message.remove_reaction(emoji, self.bot.user)
 
 
     # Fortnite
@@ -148,19 +151,32 @@ class Games(commands.Cog):
     )
     async def fortnite_store(self, ctx):
         JSON = apis.Fortnite.getStore()
-        await ctx.sendEmbed(
+
+        if ctx.channel.type == ChannelType.private or ctx.channel.permissions_for(ctx.author).manage_messages:
+            receiver = ctx.channel
+        else:
+            receiver = ctx.author
+            await ctx.sendEmbed(
+                title="Fortnite Item Shop",
+                description="Please check your direct messages.",
+                color=0x1f871e
+            )
+
+        emb = ctx.getEmbed(
             title="Fortnite Item Shop",
             authorurl="http://fortnitetracker.com/",
             authorname="Powered by Fortnitetracker"
         )
+        await receiver.send(embed=emb)
         for i in range(len(JSON)):
-            await ctx.sendEmbed(
+            emb = ctx.getEmbed(
                 title=str(JSON[i]["name"]),
                 description=("Rarity: %s \n vBucks: %s" % (JSON[i]["rarity"],JSON[i]["vBucks"])),
                 thumbnailurl=str(JSON[i]["imageUrl"]),
                 footertext="",
                 footerurl="",
             )
+            await receiver.send(embed=emb)
 
     @fortnite.command(
         name="challenges",
@@ -196,7 +212,7 @@ class Games(commands.Cog):
                 authorname="Powered by Fortnitetracker"
             )
         except KeyError:
-            raise commands.BadArgument(message="Spieler wurde auf der angegebenen Platform nicht gefunden!")
+            raise ErrorMessage(message="Spieler wurde auf der angegebenen Platform nicht gefunden!")
 
 
     # Minecraft
@@ -238,7 +254,7 @@ class Games(commands.Cog):
         api = apis.Minecraft
 
         if len(uuid) != 32:
-            raise commands.BadArgument("Eine UUID ist genau 32 Zeichen lang!")
+            raise ErrorMessage("Eine UUID ist genau 32 Zeichen lang!")
 
         JSON = api.getProfiles(uuid)
         EMBED = ctx.getEmbed(title="Minecraft Namen", description="Sortierung: Von neu bis alt.")
@@ -259,7 +275,7 @@ class Games(commands.Cog):
         api = apis.Minecraft
 
         if len(uuid) != 32:
-            raise commands.BadArgument("Eine UUID ist genau 32 Zeichen lang!")
+            raise ErrorMessage("Eine UUID ist genau 32 Zeichen lang!")
 
         JSON = api.getSkin(uuid)
         EMBED = ctx.getEmbed(title="Minecraft Skin", fields=[("Aktueller Name", JSON["name"]), ("UUID", JSON["id"])])
@@ -502,11 +518,11 @@ class Games(commands.Cog):
             textchannel = ctx.guild.get_channel(int(game.text_channel_id))
             voicechannel = ctx.guild.get_channel(int(game.voice_channel_id))
             if textchannel and voicechannel:
-                raise commands.BadArgument(message=f"Du hast bereits ein AmongUs-Spiel auf diesem Server! (ID { game.pk } - { textchannel.mention })")
+                raise ErrorMessage(message=f"Du hast bereits ein AmongUs-Spiel auf diesem Server! (ID { game.pk } - { textchannel.mention })")
             elif textchannel:
-                raise commands.BadArgument(message=f"Du hast bereits ein AmongUs-Spiel auf diesem Server, jedoch konnte der Sprachkanal nicht mehr gefunden werden! Versuche dein Game mit `/au delete` zu löschen. (ID { game.pk } - { textchannel.mention })")
+                raise ErrorMessage(message=f"Du hast bereits ein AmongUs-Spiel auf diesem Server, jedoch konnte der Sprachkanal nicht mehr gefunden werden! Versuche dein Game mit `/au delete` zu löschen. (ID { game.pk } - { textchannel.mention })")
             else:
-                raise commands.BadArgument(message=f"Du hast bereits ein AmongUs-Spiel auf diesem Server, jedoch konnte der Textkanal nicht mehr gefunden werden! (ID { game.pk })")
+                raise ErrorMessage(message=f"Du hast bereits ein AmongUs-Spiel auf diesem Server, jedoch konnte der Textkanal nicht mehr gefunden werden! (ID { game.pk })")
         else:
             category = await getAmongUsCategory(ctx.guild)
             textchannel = await category.create_text_channel(name=f"au-{ctx.author.name}#{ctx.author.discriminator}", reason="Benutzer hat AmongUs-Spiel erstellt.", topic=f"AmongUs Spiel von {ctx.author.name}#{ctx.author.discriminator}")
@@ -552,7 +568,7 @@ class Games(commands.Cog):
             )
             await ctx.author.send(embed=embed)
         else:
-            raise commands.BadArgument(message="Du hast kein AmongUs-Spiel auf diesem Server!")
+            raise ErrorMessage(message="Du hast kein AmongUs-Spiel auf diesem Server!")
 
     @amongus.command(
         name="reset",
@@ -575,9 +591,9 @@ class Games(commands.Cog):
                     description="Dein AmongUs Spiel wurde erfolgreich zurückgesetzt!"
                 )
             else:
-                raise commands.BadArgument(message="Der Sprachkanal zu deinem Spiel wurde nicht gefunden. Versuche dein Spiel mit `/amongus close` zu löschen")
+                raise ErrorMessage(message="Der Sprachkanal zu deinem Spiel wurde nicht gefunden. Versuche dein Spiel mit `/amongus close` zu löschen")
         else:
-            raise commands.BadArgument(message="Du hast kein AmongUs-Spiel auf diesem Server!")
+            raise ErrorMessage(message="Du hast kein AmongUs-Spiel auf diesem Server!")
 
     @amongus.command(
         name="apikey",
@@ -601,7 +617,7 @@ class Games(commands.Cog):
             )
             await ctx.author.send(embed=embed)
         else:
-            raise commands.BadArgument("Du hast kein AmongUs Spiel!")
+            raise ErrorMessage("Du hast kein AmongUs Spiel!")
 
 
     # VierGewinnt
@@ -645,7 +661,7 @@ class Games(commands.Cog):
             for emoji in VIERGEWINNT_NUMBER_EMOJIS[:game.width]:
                 await msg.add_reaction(emoji)
         else:
-            raise commands.BadArgument("Du kannst nicht gegen dich selbst oder Bots spielen... Wenn du einen Bot herausfordern möchtest, benutze bitte `/viergewinnt challenge`!")
+            raise ErrorMessage("Du kannst nicht gegen dich selbst oder Bots spielen... Wenn du einen Bot herausfordern möchtest, benutze bitte `/viergewinnt challenge`!")
 
     @viergewinnt.command(
         name="challenge",
@@ -777,7 +793,7 @@ class Games(commands.Cog):
                     description=game.get_description()
                 )
         else:
-            raise commands.BadArgument("Ein Spiel mit dieser ID konnte nicht gefunden werden! Möglicherweise gelöscht?")
+            raise ErrorMessage("Ein Spiel mit dieser ID konnte nicht gefunden werden! Möglicherweise gelöscht?")
 
 def setup(bot):
     bot.add_cog(Games(bot))
